
# THIS FILE IS GENERATED FROM SCIPY SETUP.PY
short_version = '0.0.7'
version = '0.0.7'
full_version = '0.0.7'
git_revision = 'd1e06bc4dced3574fc6622d10a6bdba93ec5c3cc'
release = True
if not release:
    version = full_version
